Star Wars Express Glow-In-The-Dark Train Collection
Description: Officially licensed. First-ever HO scale train featuring original art of legendary Star Wars artist Steve Anderson. FREE power pack and track!

Skip to Content
The Bradford Exchange Online Homepage

0 Items in Cart

Item no:
  917623

Tweet
Glow-In-The-Dark Star Wars Train Features Commissioned Art
Star Wars Express Train Collection

Officially licensed. First-ever HO scale train featuring original art of legendary Star Wars artist Steve Anderson. FREE power pack and track!

Train cars run on HO track, complete oval track measures 38" x 47"

From Hawthorne Village

Price:
  $79.99 US Each Issue

s&s
  $9.99 US

Available in 3 installments
of $26.66 US
Satisfaction Guaranteed:
Free Returns for 365 Days
Description

Gloriously showcasing the art of legendary Star Wars artist Steve Anderson - commissioned exclusively for this collection - this first-ever HO-scale Star Wars train collection celebrates these epic films like never before! Your dramatic collection begins with Issue One, a diesel locomotive. Soon, your collection continues with Issue Two, the coordinating Star Wars engine, which includes a FREE 14-piece HO gauge track, Issue Three, a dome car, which includes a FREE power pack and speed controller, and Issue Four, “The Force Awakens”. Additional train cars, each a separate issue, will follow.‡

Officially licensed by Lucasfilm Ltd. and available only from The Bradford Exchange, Hawthorne Village Division, each car in this real working electric train collection features scenes of dramatic movie moments and favorite Star Wars characters like Darth Vader, Storm Troopers and more. Plus, many of these powerful scenes glow in the dark! Strong demand is expected for this unique Star Wars collectible, perfect for any Star Wars fan. Don't wait, order now!

Features
This exclusive Star Wars train collection from The Bradford Exchange features:

- First-ever HO-scale Star Wars train collection featuring the specially commissioned art of legendary Star Wars artist Steve Anderson, available only from The Bradford Exchange, Hawthorne Village Division
- Officially licensed by Lucasfilm Ltd.
- Included free 14-piece HO gauge track with Issue Two and a power pack and speed controller with Issue Three
- HO-scale train collection is carefully handcrafted with precision detailing and authentic features including a solid metal chassis and steel alloy wheels to bring you years of enjoyment
- Each train car in this collection features dramatic movie moments and favorite characters like Darth Vader and more all rendered by artist Steve Anderson specially for this train

- Many powerful scenes glow in the dark for further enjoyment
- Lights up! The locomotive headlight and passenger train cars really light up for a fully illuminated display of the excitement of the Star Wars films
- The heirloom-quality trains are precisely scaled; train is designed to run on HO gauge track
- Certificates of Authenticity
- Individual train cars run on HO train track, complete oval track measures 38" x 47"; 96.5 cm x 119.4 cm

Subscription
Ordering a Collection by Subscription Plan is for Smart Collectors:

- Reserves the collectible Star Wars Express Train Collection from The Bradford Exchange, Hawthorne Village Division in your name so you never risk an increase on the price of other collectibles in this collection
- ‡Each issue will be shipped to you for your review, about one every month or two (pending availability), at the same low issue price and charged to the credit card on which your order was placed. No need to order each one separately

- You may cancel your collection at any time with no obligation
- "Issue One - the diesel locomotive," will be followed by "Issue Two - engine and FREE 14-piece track set," "Issue Three - a dome car with FREE power pack and speed controller," “Issue Four - The Force Awakens,” and additional collectible Star Wars train cars as they become available

Buy This Item Now:
  Glow-In-The-Dark Star Wars Train Features Commissioned Art

# Star Wars Train Collection Makes a Unique Star Wars Collectible for Any Star Wars Fan! Star Wars Art by Artist Steve Anderson

Item no:
  917623

Price:
  $79.99 US

s&s
  $9.99 US

Available in 3 installments
of $26.66 US
Fine collectible. Not intended for children under 14.
©2011 Lucasfilm Ltd & TM. All rights reserved.
©2011 Hawthorne
by Collectibles Today®
0 Items in Cart
Customer Service

- Order Status
- Payment History
- Manage My Account
- Frequently Asked Questions
- Personalization Policy
- Contact Us

Company Info

- About Us
- Employment
- Privacy Policy
- Affiliates
- Site Map
- Connect With Us
- Supply Chain
- Visit Our Blog

Shop by Department

- Jewelry
- Personalized Gifts
- Apparel &
  Accessories
- Collectibles
- Home Décor

- Personalized Jewelry
- Women's Rings
- Graduation Gifts
- Sports Collectibles
- Disney Collectibles
- Shop by Theme

Shop with Confidence

FREE Return Shipping

Satisfaction Guaranteed up to 365 Days

Sign up now for E-mail Updates
Enter E-Mail Address
Enter E-Mail Address
Other Sites

- The Ashton-Drake Galleries Online
- The Hamilton Collection Online
- Bradford Exchange Checks
- Artful Impressions
- International Sites